@@ -275,15 +275,6 @@ void override_account(account_t *acc1, account_t *acc2);
  */
 int check_account(account_t *acc, int sendmail_mode, char **errstr);
 
-/*
- * get_password_eval()
- *
- * Evaluates command in 'arg' and stores result in 'buf' (which is allocated).
- * Returns CONF_EIO if command exectution failed, otherwise CONF_EOK. On error,
- * *errstr will contain an error string.
- */
-int get_password_eval(const char *arg, char **buf, char **errstr);
-
 /*
  * expand_from()
  *
